@@ -17,8 +17,7 @@ colnames(BasinObs2) <- letters[seq_along(colnames(BasinObs2))]
 
 test_that("ObsDF with custom column names", {
   expect_equal(
-    object   = PrepGR(ObsDF = BasinObs, HydroModel = "GR4J", CemaNeige = FALSE)
-    ,
+    object   = PrepGR(ObsDF = BasinObs, HydroModel = "GR4J", CemaNeige = FALSE),
     expected = PrepGR(ObsDF = BasinObs2, HydroModel = "GR4J", CemaNeige = FALSE),
   )
 })
@@ -27,8 +26,7 @@ test_that("ObsDF with custom column names", {
 
 test_that("ObsDF is a tibble data.frame", {
   expect_equal(
-    object   = PrepGR(ObsDF = BasinObs, HydroModel = "GR4J", CemaNeige = FALSE)
-    ,
+    object   = PrepGR(ObsDF = BasinObs, HydroModel = "GR4J", CemaNeige = FALSE),
     expected = PrepGR(ObsDF = as_tibble(BasinObs), HydroModel = "GR4J", CemaNeige = FALSE),
   )
 })
